==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/MarketFacilitationIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MarketFacilitationIndexIndicatorDescription } from "./MarketFacilitationIndexIndicatorDescription";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicatorDescriptionMetadata, _super);
    function MarketFacilitationIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MarketFacilitationIndexIndicatorDescriptionMetadata.b = function (a) {
        if (MarketFacilitationIndexIndicatorDescriptionMetadata.a == null) {
            MarketFacilitationIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MarketFacilitationIndexIndicatorDescriptionMetadata.c(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
        if (a.k(MarketFacilitationIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ab(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.d = function (a) {
        MarketFacilitationIndexIndicatorDescriptionMetadata.b(a);
        a.ad("MarketFacilitationIndexIndicator", function () { return new MarketFacilitationIndexIndicatorDescription(); });
        a.ac("MarketFacilitationIndexIndicator", MarketFacilitationIndexIndicatorDescriptionMetadata.a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.$t = markType(MarketFacilitationIndexIndicatorDescriptionMetadata, 'MarketFacilitationIndexIndicatorDescriptionMetadata');
    MarketFacilitationIndexIndicatorDescriptionMetadata.a = null;
    return MarketFacilitationIndexIndicatorDescriptionMetadata;
}(Base));
export { MarketFacilitationIndexIndicatorDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/MarketFacilitationIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MarketFacilitationIndexIndicatorDescription } from "./MarketFacilitationIndexIndicatorDescription";
/**
 * @hidden
 */
var MarketFacilitationIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MarketFacilitationIndexIndicatorDescriptionMetadata, _super);
    function MarketFacilitationIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MarketFacilitationIndexIndicatorDescriptionMetadata.b = function (a) {
        if (MarketFacilitationIndexIndicatorDescriptionMetadata.a == null) {
            MarketFacilitationIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MarketFacilitationIndexIndicatorDescriptionMetadata.c(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
        if (a.k(MarketFacilitationIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.c = function (a) {
        ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.d = function (a) {
        MarketFacilitationIndexIndicatorDescriptionMetadata.b(a);
        a.ae("MarketFacilitationIndexIndicator", function () { return new MarketFacilitationIndexIndicatorDescription(); });
        a.ad("MarketFacilitationIndexIndicator", MarketFacilitationIndexIndicatorDescriptionMetadata.a);
    };
    MarketFacilitationIndexIndicatorDescriptionMetadata.$t = markType(MarketFacilitationIndexIndicatorDescriptionMetadata, 'MarketFacilitationIndexIndicatorDescriptionMetadata');
    MarketFacilitationIndexIndicatorDescriptionMetadata.a = null;
    return MarketFacilitationIndexIndicatorDescriptionMetadata;
}(Base));
export { MarketFacilitationIndexIndicatorDescriptionMetadata };
